"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _common = require("./common");

// Weighted moving average
var _default = function _default(data, size) {
  var length = data.length;

  if (size <= 1) {
    return data.slice();
  }

  if (size > length) {
    return Array(length);
  }

  var ret = [];
  var denominator = size * (size + 1) / 2;
  var prepare = size - 1;
  var sum = 0;
  var numerator = 0;
  var datum = 0;
  var i = 0;
  var real = -1;

  for (; i < prepare; i++) {
    datum = data[i];

    if ((0, _common.isNumber)(datum)) {
      sum += datum;
      numerator += (i + 1) * datum;
    }
  }

  for (; i < length; i++, real++) {
    datum = data[i];

    if ((0, _common.isNumber)(datum)) {
      sum += datum;
      numerator += size * datum;
    }

    if (real >= 0 && (0, _common.isNumber)(data[real])) {
      sum -= data[real];
    }

    ret[i] = numerator / denominator;
    numerator -= sum;
  }

  return ret;
};

exports["default"] = _default;